@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        demo/wxThread.pm
+## Name:        wxThread.pm
 ## Purpose:     wxPerl demo helper for threads
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     30/03/2002
-## RCS-ID:      $Id: wxThread.pm,v 1.6 2004/12/21 21:12:46 mbarbon Exp $
-## Copyright:   (c) 2002-2004 Mattia Barbon
+## Created:     30/ 3/2002
+## RCS-ID:      
+## Copyright:   (c) 2002 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -77,19 +77,19 @@ sub DESTROY {
   my( $this, $event ) = @_;
 
   threads::shared::lock_enabled( $joined );
-  #print "Join begin\n";
+  print "Join begin\n";
   $keep_going = 0;
   if( !$joined ) {
-    #print "Join start\n";
+    print "Join start\n";
     $joined = 1;
     foreach my $i ( @{$this->{THREADS}} ) {
       $i->join();
     }
-    #print "Join end\n";
+    print "Join end\n";
   }
 
-  #$this->SUPER::DESTROY();
-  #print "Join leave\n";
+  $this->SUPER::DESTROY();
+  print "Join leave\n";
 }
 
 # this should really do something useful, really
@@ -100,7 +100,7 @@ sub entry_point {
   threads::shared::share( $value );
 
   for(;;) {
-    Wx::MilliSleep( 200 + rand( 1000 ) );
+    Wx::Usleep( 200 + rand( 1000 ) );
 
     last unless $keep_going;
     my $x = Wx::PlThreadEvent->new( -1, $ThreadDemoWin::MY_ID, $value );
