@@ -15,15 +15,11 @@ package Wx::DND;
 use Wx;
 use strict;
 
-require DynaLoader;
-
-use vars qw(@ISA $VERSION);
+use vars qw($VERSION);
 
 $VERSION = '0.01';
 
-@ISA = qw(DynaLoader);
-
-bootstrap Wx::DND;
+Wx::wx_boot( 'Wx::DND', $VERSION );
 
 use Wx::DropSource;
 
